; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;



;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1



;-| Super Motions |--------------------------------------------------------
[Command]
name="SUPER2"
command=~D,DF,F,D,DF,F,a
time=30

[Command]
name="SUPER2"
command=~D,DF,F,D,DF,F,b
time=30

[Command]
name="SUPER2"
command=~D,DF,F,D,DF,F,c
time=30

[Command]
name="REVERSESUPER2"
command=~D,DB,B,b
time=15
[Command]
name="REVERSESUPER2"
command=~F,D,DB,B,b
time=15
[Command]
name="REVERSESUPER2"
command=~D,DB,B,c
time=15
[Command]
name="REVERSESUPER2"
command=~F,D,DB,B,c
time=15

[Command]
name="SUPER"
command=~D,DF,F,D,DF,F,x
time=30

[Command]
name="SUPER"
command=~D,DF,F,D,DF,F,y
time=30

[Command]
name="SUPER"
command=~D,DF,F,D,DF,F,z
time=30


[Command]
name="SUPER3"
command=~D,B, D, F, x
time=30

[Command]
name="SUPER3"
command=~D,B, D, F, y
time=30

[Command]
name="SUPER3"
command=~D,B, D, F, z
time=30
;-| Special Motions |------------------------------------------------------


[Command]
name = "QCF_a"
command = ~D, DF, F, a
time=20


[Command]
name = "QCF_c"
command = ~D, DF, F, c
time=20

[Command]
name = "KANG_B"
command = ~D, DF, F, b
time=20

[Command]
name = "KANG_C"
command = ~D, DF, F, c
time=20

[Command]
name = "EX_KANG_B"
command = ~D, DF, F, a+b
time=20

[Command]
name = "EX_KANG_C"
command = ~D, DF, F, b+c
time=20

[Command]
name = "EX_KANG_B"
command = ~D, DF, F, a+c
time=20

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time=20

[Command]
name = "QCF_y"
command = ~D, DF, F, y
time=20

[Command]
name = "QCF_z"
command = ~D, DF, F, z
time=20


; SPINNING PILE DRIVER
;================
[Command]
name = "DRIVER_x"
command = ~D, DB, B, x
time=20
[Command]
name = "DRIVER_y"
command = ~D, DB, B, y
time=20
[Command]
name = "DRIVER_z"
command = ~D, DB, B, z
time=20

; DIVE KICK
;================
[command]
name = "DiveKick"
command = /D, c
[command]
name = "DiveKick"
command = ~D, DF, F, c

; EX DIVE KICK
;================
[command]
name = "EX_DiveKick"
command = /D, a+b
[command]
name = "EX_DiveKick"
command = /D, b+c
[command]
name = "EX_DiveKick"
command = /D, a+c
[command]
name = "EX_DiveKick"
command = ~DF, F, a+b
[command]
name = "EX_DiveKick"
command = ~DF, F, b+c
[command]
name = "EX_DiveKick"
command =~DF, F, a+c

[Command]
name = "EX_NOSEDIVE"
command = ~D, DF, F, x+y
time=20

[Command]
name = "EX_NOSEDIVE"
command = ~D, DF, F, y+z
time=20

[Command]
name = "EX_NOSEDIVE"
command = ~D, DF, F, x+z
time=20

[Command]
name = "NOSEDIVE"
command = ~D, DF, F, x
time=20

[Command]
name = "NOSEDIVE2"
command = ~D, DF, F, y
time=20

[Command]
name = "NOSEDIVE3"
command = ~D, DF, F, z
time=20

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "super jump"
command = $D, $U
time = 15
;-| 2/3 Button Combination |-----------------------------------------------


[Command]
name = "guardpush"
command = x+y
time = 4

[Command]
name = "guardpush"
command = y+z
time = 4

[Command]
name = "guardpush"
command = x+z
time = 4

[Command]
name = "guardpush"
command = x+y+z
time = 4 


[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1


[Command]
name = "x+a" 
command = x+a
time = 1

[Command]
name = "x+a" 
command = a+x
time = 1


[Command]
name = "z+c" 
command = $UF,z+c
time = 1
[Command]
name = "z+c" 
command = $U,z+c
time = 1
[Command]
name = "z+c" 
command = $F,z+c
time = 1
[Command]
name = "z+c" 
command = z+c
time = 1
;[Command]
;name = "z+c" 
;command = /z+c
;time = 1


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1


[Command]
name = "fwddown"
command = $FD
time = 1


[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;SUPERS
;----------------------------------
;=================================
; CHUCK IT OUT SUPER COMBO
[State -1, Super]
type = ChangeState
value = 3000
triggerall= command= "SUPER" && power>=1000
triggerall = command != "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=250&&movecontact
trigger8 = stateno=400&&animelem>=8&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=440&&movecontact
trigger12= stateno=450&&movecontact
trigger13= anim=851&&animelemtime(7)>=1;&&animelemtime(8)<=7

; FOOT UPRISING SUPER COMBO - ON THE GROUND
[State -1, Super2]
type = ChangeState
value = 3100
triggerall= command= "SUPER2" && power>=1000
triggerall= command != "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=250&&movecontact
trigger8 = stateno=400&&animelem>=8&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=440&&movecontact
trigger12= stateno=450&&movecontact
trigger13= anim=851&&animelemtime(7)>=1

; FOOT UPRISING SUPER COMBO - IN THE AIR
[State -1, Super3]
type = ChangeState
value = 3200
triggerall= command= "SUPER2" && power>=1000
triggerall= statetype!=S&&statetype!=C
trigger1 = statetype =A
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=620&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact
trigger7 = (stateno=[650,651])&&movecontact
trigger8 = stateno=1000&&movecontact
trigger9 = stateno=1010&&movecontact
trigger10= stateno=3100&&movecontact
trigger11= StateNo=3040&&MoveContact
trigger12= (StateNo =1011) && MoveContact
trigger12= (Anim=1000&&hitcount>=2)
trigger13= (StateNo =1012) && MoveContact
trigger13= (Anim=1010&&hitcount>=2)

; GRAPPLE HOOK HURRICANE HYPER COMBO
[State -1, Hyper]
type = ChangeState
value = 3300
triggerall= command= "SUPER3" && power>=3000
triggerall!=command = "DRIVER_x" || command = "DRIVER_y" || command = "DRIVER_z"
triggerall = command!= "SUPER"
triggerall=command != "holddown"
trigger1 = statetype=S||statetype=C
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=250&&movecontact
trigger8 = stateno=400&&animelem>=8&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=440&&movecontact
trigger12= stateno=450&&movecontact
;=============================================================
;SPECIALs
;----------------------------------
;=================================
; SPINNING PILE DRIVER
[State -1, SPINNING PILE DRIVER]
type = ChangeState
value = 850
triggerall = command = "DRIVER_x" || command = "DRIVER_y" || command = "DRIVER_z"
triggerall =command!= "SUPER3"
triggerall = command!="holddown"
triggerall = statetype != A
trigger1 = statetype=S
trigger1 = ctrl
;=================================
;NoseDive 
[State -1, NoseDive]
type = ChangeState
value = 2000
triggerall = (command = "NOSEDIVE"||command ="NOSEDIVE2"||command="NOSEDIVE3")&& statetype!=S
triggerall = command != "EX_NOSEDIVE"
triggerall = command != "z"||command!="down_z"
triggerall = command != "y"||command!="down_y"
triggerall = command !="holddown"
trigger1 = pos y<=-50
trigger1= ctrl  
trigger2 = StateNo = 40
trigger3 = (StateNo = 600) && MoveContact
trigger3 = Pos Y <=-30
trigger4 = (StateNo = 610) && MoveContact
trigger4 = Pos Y <=-30
trigger5 = (StateNo = 620) && MoveContact
trigger5 = Pos Y <=-30
trigger6 = (StateNo = 630) && MoveContact
trigger6 = Pos Y <=-30
trigger7 = (StateNo = 640) && MoveContact
trigger7 = Pos Y <=-30
trigger8 = (StateNo = 650) && MoveContact
trigger8 = Pos Y <=-30
trigger9 = stateno=651
trigger9 = pos y<=-30
trigger10= (StateNo =1000) && MoveContact
trigger11= (StateNo =1010) && MoveContact
trigger12= (StateNo =1011) && MoveContact
trigger12= (Anim=1000&&hitcount>=2)
trigger13= (StateNo =1012) && MoveContact
trigger13= (Anim=1010&&hitcount>=2)
;=================================
;EX NoseDive 
[State -1, EX NoseDive]
type = ChangeState
value = 2010
triggerall = command = "EX_NOSEDIVE"&& statetype!=S&&power>=500
triggerall =!command = "NOSEDIVE"||!command ="NOSEDIVE2"||!command="NOSEDIVE3"
triggerall = command != "z"||command!="down_z"
triggerall = command != "y"||command!="down_y"
triggerall = command !="holddown"
trigger1 = pos y<=-50
trigger1= ctrl  
trigger2 = StateNo = 40
trigger3 = (StateNo = 600) && MoveContact
trigger3 = Pos Y <=-30
trigger4 = (StateNo = 610) && MoveContact
trigger4 = Pos Y <=-30
trigger5 = (StateNo = 620) && MoveContact
trigger5 = Pos Y <=-30
trigger6 = (StateNo = 630) && MoveContact
trigger6 = Pos Y <=-30
trigger7 = (StateNo = 640) && MoveContact
trigger7 = Pos Y <=-30
trigger8 = (StateNo = 650) && MoveContact
trigger8 = Pos Y <=-30
trigger9 = stateno=651
trigger9 = pos y<=-30
trigger10= (StateNo =1000) && MoveContact
trigger11= (StateNo =1010) && MoveContact
trigger12= (StateNo =1011) && MoveContact
trigger12= (Anim=1000&&hitcount>=2)
trigger13= (StateNo =1012) && MoveContact
trigger13= (Anim=1010&&hitcount>=2)
,------------------------------------------
; Kangaroo Kick
[State -1, Kangaroo Kick]
type = ChangeState
value = 1010
triggerall= statetype!=A
triggerall= Pos Y >=0
triggerall= Vel Y >=0
triggerall = command = "KANG_B"
triggerall = command!= "KANG_C"
triggerall = command!= "EX_KANG_B"
triggerall = command!= "EX_KANG_C"
triggerall = command!="holddown"
trigger1 = statetype=S&&Pos Y=0
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 != stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=241&&movecontact
trigger8 = stateno=250&&movecontact
trigger10 = hitcount>=3&&stateno=220&&movecontact
trigger10= p2bodydist X>20&&(command="b"&&command!="holddown")
trigger11= stateno=400&&animelem>=8&&movecontact
trigger12= stateno=410&&movecontact
trigger13= stateno=430&&movecontact
trigger14= stateno=440&&movecontact
;---------------------------------------------------------------------------
; Kangaroo Kick
[State -1, Kangaroo Kick]
type = ChangeState
value = 1000
triggerall= statetype!=A
triggerall= Pos Y >=0
triggerall= Vel Y >=0
triggerall = command = "KANG_C"
triggerall = command!= "KANG_B"
triggerall = command!= "EX_KANG_B"
triggerall = command!= "EX_KANG_C"
triggerall = command!="holddown"
trigger1 = statetype=S&&Pos Y=0
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5!= stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=241&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&animelem>=8&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=430&&movecontact
trigger12= stateno=440&&movecontact
;--------------------------------------
;EX Kangaroo Kick
[State -1, EX Kangaroo Kick]
type = ChangeState
value = 1011
triggerall= statetype!=A
triggerall= Pos Y >=0
triggerall= Vel Y >=0
triggerall = command = "EX_KANG_C"&&power >=500
triggerall = command!= "EX_KANG_B"
triggerall = command!="holddown"
trigger1 = statetype=S&&Pos Y=0
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 != stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=241&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&animelem>=8&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=430&&movecontact
trigger12= stateno=440&&movecontact
,------------------------------------------
;EX Kangaroo Kick
[State -1, EX Kangaroo Kick UP]
type = ChangeState
value = 1012
triggerall= statetype!=A
triggerall= Pos Y >=0
triggerall= Vel Y >=0
triggerall = command = "EX_KANG_B"&&power >=500
triggerall = command!= "EX_KANG_C"
trigger1 = statetype=S&&Pos Y=0
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 != stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=241&&movecontact
trigger8 = stateno=250&&movecontact
trigger10 = hitcount>=3&&stateno=220&&movecontact
trigger10= p2bodydist X>20&&(command="b"&&command!="holddown")
trigger11= stateno=400&&animelem>=8&&movecontact
trigger12= stateno=410&&movecontact
trigger13= stateno=430&&movecontact
trigger14= stateno=440&&movecontact
;---------------------------------------------------------------------------
; Dive Kick
[State -1, Dive Kick]
type = ChangeState
value = 1020
triggerall = command!= "EX_DiveKick"
triggerall = command = "DiveKick"
triggerall= pos y <= -40
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = Pos Y <=-30
trigger3 = stateno=610&&movecontact
trigger3 = Pos Y <=-30
trigger4 = stateno=630&&movecontact
trigger4 = Pos Y <=-30
trigger5 = stateno=640&&movecontact
trigger5 = Pos Y <=-30
trigger6 = stateno=650&&movecontact
trigger6 = Pos Y <=-30
;---------------------------------------------------------------------------
; Dive Kick
[State -1, Dive Kick]
type = ChangeState
value = 1022
triggerall = stateno=1021
triggerall = command!= "EX_DiveKick"
triggerall = command = "DiveKick"
triggerall= pos y <= -40
triggerall = statetype!=S
trigger1 = statetype!=C
trigger1 = ctrl
;---------------------------------------------------------------------------
;EX Dive Kick
[State -1, EX Dive Kick]
type = ChangeState
value = 1024
triggerall = command = "EX_DiveKick"&&power>=500
triggerall= pos y <= -65
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = Pos Y <=-65
trigger3 = stateno=610&&movecontact
trigger3 = Pos Y <=-65
trigger4 = stateno=630&&movecontact
trigger4 = Pos Y <=-65
trigger5 = stateno=640&&movecontact
trigger5 = Pos Y <=-65
trigger6 = stateno=650&&movecontact
trigger7 = stateno=651&&numtarget&&pos y<=-30
;---------------------------------------------------------------------------
;EX Dive Kick
[State -1, EX Dive Kick]
type = ChangeState
value = 1024
triggerall = var(13)<=2
triggerall = stateno=1021
triggerall = command = "EX_DiveKick"&&power>=500
triggerall= pos y <= -65
triggerall = statetype!=S
trigger1 = statetype!=C
trigger1 = ctrl
trigger2= stateno=651&&numtarget
;---------------------------------------------------------------------------
; EVADE Rolling Dodge Forward
[State -1, Rolling Dodge Forward]
type = ChangeState
value = 700
triggerall=numhelper(715)!=1
triggerall = command = "x+a"&&command="holddown" ||command="x+a" && command!="holddown" 
triggerall = command != "holdback"
trigger1 = statetype!=A
trigger1 = ctrl
;---------------------------------------------------------------------------
; EVADE Rolling Dodge Back
[State -1, Rolling Dodge Back]
type = ChangeState
value = 710
triggerall=numhelper(715)!=1
triggerall = command = "holdback" && (command = "x+a")
triggerall = command != "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
;===========================================================================
;--------------------------------------------------------------------------
;Guard Push
[State -1]
type = ChangeState
value = 720
triggerall = var(10) != 1&&command = "guardpush"&&statetype = S&&p2life!=0
trigger1 = stateno = [150,153]
;-------------------------------------
[State -1]
type =ChangeState
value = 725
triggerall = var(10) != 1&&command = "guardpush"&&statetype = C&&p2life!=0
trigger1 = stateno = [150,153]
;-------------------------------------
[State -1]
type =ChangeState
value = 730 
triggerall = var(10) != 1&&command = "guardpush"&&statetype = A&&p2life!=0
trigger1 = stateno = [154,155]
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
;==============
; Super Jump
;===============
[State -1, Super Jump]
type = ChangeState
value = 55
triggerall = command = "super jump"
trigger1 = statetype != A
trigger1 = ctrl = 1 || (stateno=[100,101])
;---------------------------------------------------------------------------
; Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y" || command = "z"
triggerall = statetype!=A
triggerall = statetype!=C
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype != A) 
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype != A) 
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
; Throw
[State -1, Throw]
type = ChangeState
value = 805
triggerall = command = "b" || command = "c"
triggerall = statetype!=A
triggerall = statetype!=C
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype != A)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype != A)
trigger2 = p2movetype != H
;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall =command = "s"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 5110 && time = [9, 16]
trigger3 = stateno=400&&(animelem=8&&movecontact)
trigger4 = stateno=410&&movecontact
trigger5 = stateno=430&&movecontact
trigger6 = stateno=440&&movecontact
trigger7 = stateno=450&&movecontact


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1= ctrl || (stateno=[100,101])
trigger2 = stateno=858&&animelemtime(7)>=1
;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1= ctrl || (stateno=101);[100,101])
trigger2 = (stateno = 200) && movecontact
trigger3 = stateno=858&&animelemtime(7)>=2
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1= ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=240&&movecontact
trigger5 = stateno=241&&movecontact
trigger6 = stateno=400&&(animelem=8&&movecontact)
trigger7 = stateno=410&&movecontact
trigger8 = stateno=430&&movecontact
trigger9 = stateno=440&&movecontact
trigger10= stateno=450&&movecontact
trigger11= stateno=858&&animelemtime(7)>=2
;-------------------------------------
;Stand Strong Punch 2
[State -1, Stand Strong Punch 2]
type = ChangeState
value = 221
triggerall=(stateno=220&&movehit)&&command = "z"
triggerall = command != "holddown"
triggerall = command != "SUPER"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1 = ctrl
trigger2 = stateno=250&&movecontact
trigger2 = time >3
;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1= ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=250&&movecontact
trigger8 = stateno=400&&(animelem=8&&movecontact)
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=440&&movecontact
trigger12= stateno=450&&movecontact
;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command!= "KANG_B"
triggerall = command!= "holddown"
triggerall = command!= "downfwd"
triggerall = command!= "fwddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1= ctrl || (stateno=[100,101])
trigger2 = (stateno = 200) && movecontact
trigger2 = time > 5
trigger3 = stateno=220&&movecontact
trigger3 = p2bodydist X<=20&&(command="b"&&command!="holddown")
trigger4 = stateno=430&&movecontact
trigger5 = stateno=440&&movecontact
trigger6 = stateno=210&&movecontact
trigger7 = stateno=858&&animelemtime(7)>=2
----------------------------------------
; Standing Medium Kick2
[State -1, Standing Medium Kick2]
type = ChangeState
value = 241
triggerall = stateno=240&&movecontact
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command!= "KANG_C"
triggerall = command!= "holddown"
triggerall = command!= "downfwd"
triggerall = command!= "fwddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 =  statetype = S
trigger1= ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=430&&movecontact
trigger8 = stateno=440&&movecontact
trigger9 = stateno=858&&animelemtime(7)>=2
;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = Pos Y=0
trigger1 =  statetype!= A||statetype!=S
trigger1 = ctrl || (stateno=101);[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=250&&movecontact
;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = Pos Y=0
trigger1 =  statetype!= A||statetype!=S
trigger1 = ctrl || (stateno=101);[100,101])
trigger2 = (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)
trigger3 = stateno=200&&movecontact
trigger4 = stateno=210&&movecontact
trigger5 = stateno=220&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=241&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&(animelem=8&&movecontact)
trigger10= stateno=430&&movecontact
trigger11= stateno=858&&animelemtime(7)>=2
;---------------------------------------------------------------------------
; Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
triggerall = command!= "SUPER3"
triggerall = command!= "SUPER"
triggerall = command!= "QCF_c"
triggerall = Pos Y=0
trigger1 =  statetype!= A||statetype!=S
trigger1 = ctrl || (stateno=101);[100,101])
trigger2 = stateno=410&&movecontact
trigger3 = stateno=200&&movecontact
trigger4 = stateno=210&&movecontact
trigger5 = stateno=220&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=241&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&(animelem=8&&movecontact)
trigger10= stateno=430&&movecontact
trigger11= stateno=440&&movecontact
trigger12= stateno=450&&movecontact
trigger13= stateno=858&&animelemtime(7)>=2
;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = Pos Y=0
trigger1 =  statetype!= A||statetype!=S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=400&&(animelem=8&&movecontact)
trigger3 = stateno=200&&movecontact
trigger4 = stateno=210&&movecontact
trigger5 = stateno=220&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=241&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=858&&animelemtime(7)>=2
;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = command!= "KANG_B"
triggerall = Pos Y=0
trigger1 =  statetype!= A||statetype!=S
trigger1 =  statetype = C
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=250&&movecontact
trigger8 = stateno=400&&(animelem=8&&movecontact)
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=858&&animelemtime(7)>=2
;---------------------------------------------------------------------------
; Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
triggerall = command!= "KANG_C"
triggerall = Pos Y=0 
triggerall!=stateno=221&&movecontact
trigger1 =  statetype!= A||statetype!=S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=241&&movecontact
trigger7 = stateno=250&&movecontact
trigger7 = numtarget(460)<=0
trigger8 = stateno=400&&(animelem=8&&movecontact)
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=440&&movecontact
trigger12= stateno=858&&animelemtime(7)>=2
;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno=600&&time>9&&movecontact
trigger4 = stateno=610&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking
trigger4 = stateno=640&&movecontact
;---------------------------------------------------------------------------
; Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall=numhelper(713)<=0
triggerall = command = "z"
triggerall = command!= "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = numhelper(713)<=0
trigger2 = pos y<=-30
trigger3 = stateno=610&&movecontact
trigger3 = numhelper(713)<=0
trigger3 = pos y<=-35
trigger4 = stateno=630&&movecontact
trigger4 = numhelper(713)<=0
trigger4 = pos y<=-30
trigger5 = stateno=640&&movecontact
trigger5 = numhelper(713)<=0
trigger5 = pos y<=-30
;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
triggerall = command!= "SUPER2"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno=600&&movecontact
trigger4 = stateno=610&&movecontact
trigger5 = stateno=640&&movecontact

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
triggerall = command!= "SUPER2"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno=600&&movecontact
trigger4 = stateno=610&&movecontact
trigger5 = stateno=630&&movecontact

;---------------------------------------------------------------------------
; Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command ="c"
triggerall = command!="z"
triggerall = command!= "DiveKick"
triggerall = command!= "SUPER2"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=630&&movecontact
trigger5 = stateno=640&&movecontact
;---------------------------------------------------------------------------
; Jump Launcher
[State -1, Jump Launcher]
type = ChangeState
value = 660
triggerall=numhelper(460)<=0
triggerall=numhelper(713)<=0
triggerall=numhelper(714)<=0
triggerall = power>=500&&command = "z+c"
triggerall !=command="z"
triggerall !=command="c"
triggerall = command!= "DiveKick"
triggerall = command!= "SUPER2"
trigger1 = pos y<=-50
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = pos y<=-30
trigger3 = stateno=610&&movecontact
trigger3 = pos y<=-30
trigger4 = stateno=630&&movecontact
trigger4 = pos y<=-30
trigger5 = stateno=640&&movecontact
trigger5 = pos y<=-30
trigger6 = stateno=650&&movecontact
trigger6 = (Enemynear(0), pos y>=0)
trigger6 = pos y<=-30